# QSTN
![Overview](overview.svg)

QSTN is a Python framework designed to facilitate the creation of robust inference experiments with Large Language Models based around questionnaires. It provides a full pipeline from perturbation of prompts, to choosing Response Generation Methods, inferencing and finally parsing of the output. QSTN supports both local inference with vllm and remote inference via the OpenAI API.

Detailed information and guides are available in our [documentation](https://qstn.readthedocs.io/en/latest/). Tutorial notebooks can also be found in this [repository](https://github.com/dess-mannheim/QSTN/tree/main/docs/guides).

## Installation

To install the project and dependencies you can use `pip`.

```bash
pip install qstn
```

Or install this package from source:

```bash
pip install git+https://github.com/dess-mannheim/QSTN.git
```

## Citation

This package will soon have a arxiv paper.
